@@ -39,8 +39,12 @@ public:
     QRectF boundingRect() const;
     void paint(QPainter* pPainter, const QStyleOptionGraphicsItem* pOption, QWidget* pWidget);
 
+public slots:
+    void onHoldTimeout();
+
 signals:
     void clicked();
+    void clickAndHold();
 
 protected:
     virtual void mousePressEvent(QGraphicsSceneMouseEvent* pEvent);
@@ -51,6 +55,8 @@ private:
     QPixmap m_pxIcon;           ///< The icon for the button
     State m_State;              ///< The current state of the button
     QPointF m_IconOffset;       ///< The offset for the icon inside the button
+    QTimer m_HoldTimer;         ///< Timer for the click and hold
+    bool m_bIgnoreRelease;      ///< Used to skip the clicked() when clickAndHold() is emitted
 };
 
 #endif // CUSTOMBUTTON_H
