@@ -32,7 +32,7 @@ int main(int argc, char *argv[])
     CMainWindow w;
     w.intialize();
 
-#ifndef Q_WS_HILDON
+#ifndef Q_WS_MAEMO_5
     w.resize(800, 480);
     w.show();
 #else
