@@ -17,11 +17,12 @@
 
 #include "mainwindow.h"
 #include "numberitem.h"
+#include "aboutdialog.h"
 
 QColor CMainWindow::c_Colors[Color_Last];
 QPixmap* CMainWindow::c_Pixmaps[Pixmap_Last] = {0};
 
-#ifdef Q_WS_HILDON
+#ifdef Q_WS_MAEMO_5
 //-----------------------------------------------------------------------------
 /**
 ** Callback for display state changes.
@@ -64,6 +65,7 @@ CMainWindow::CMainWindow(QWidget* pParent)
 
     m_bCountDown = false;
     m_bShowTime = false;
+    m_StartTime = 0;
 
     qRegisterMetaType< QList<int> >("QList<int>");
 
@@ -83,7 +85,7 @@ CMainWindow::CMainWindow(QWidget* pParent)
     bOk = connect(&m_Timer, SIGNAL(timeout()), this, SLOT(onTimeout()));
     Q_ASSERT(bOk);
 
-#ifdef Q_WS_HILDON
+#ifdef Q_WS_MAEMO_5
     m_pOssoContext = osso_initialize("tickstill", "1.0", FALSE, NULL);
     if (m_pOssoContext == NULL)
     {
@@ -122,7 +124,7 @@ CMainWindow::~CMainWindow()
         c_Pixmaps[i] = NULL;
     }
 
-#ifdef Q_WS_HILDON
+#ifdef Q_WS_MAEMO_5
     if (m_pOssoContext != NULL)
     {
         osso_deinitialize(m_pOssoContext);
@@ -245,6 +247,8 @@ void CMainWindow::intialize()
 
     bOk = connect(m_pButtonReset, SIGNAL(clicked()), this, SLOT(onReset()));
     Q_ASSERT(bOk);
+    bOk = connect(m_pButtonReset, SIGNAL(clickAndHold()), this, SLOT(onRestart()));
+    Q_ASSERT(bOk);
     bOk = connect(m_pButtonStart, SIGNAL(clicked()), this, SLOT(onStart()));
     Q_ASSERT(bOk);
 
@@ -286,7 +290,6 @@ void CMainWindow::intialize()
 
     // Create menu items
     QAction* aboutAction = new QAction(tr("&About"), this);
-    QAction* chooseAlarmAction = new QAction(tr("&Choose alarm..."), this);
     m_ShowClockAction = new QAction(tr("&Show clock"), this);
     m_KeepBacklightAction = new QAction(tr("&Keep backlight on"), this);
     m_KeepBacklightAction->setCheckable(true);
@@ -295,9 +298,8 @@ void CMainWindow::intialize()
     m_PresetsAction = new QAction(tr("&Presets"), this);
 
     // Add item into menu
-#if defined(Q_WS_HILDON)
+#if defined(Q_WS_MAEMO_5)
     menuBar()->addAction(aboutAction);
-    menuBar()->addAction(chooseAlarmAction);
     menuBar()->addAction(m_ShowClockAction);
     menuBar()->addAction(m_KeepBacklightAction);
     menuBar()->addAction(m_PresetsAction);
@@ -306,7 +308,6 @@ void CMainWindow::intialize()
     // else File menu
     QMenu* menu = new QMenu(tr("&File"), this);
     menu->addAction(aboutAction);
-    menu->addAction(chooseAlarmAction);
     menu->addAction(m_ShowClockAction);
     menu->addAction(m_KeepBacklightAction);
     menu->addAction(m_NightModeAction);
@@ -322,8 +323,6 @@ void CMainWindow::intialize()
 
     bOk = connect(aboutAction, SIGNAL(triggered()), this, SLOT(onAbout()));
     Q_ASSERT(bOk);
-    bOk = connect(chooseAlarmAction, SIGNAL(triggered()), this, SLOT(onChooseAlarm()));
-    Q_ASSERT(bOk);
     bOk = connect(m_ShowClockAction, SIGNAL(triggered()), this, SLOT(onShowClock()));
     Q_ASSERT(bOk);
     bOk = connect(m_NightModeAction, SIGNAL(triggered()), this, SLOT(onNightMode()));
@@ -344,6 +343,11 @@ void CMainWindow::stopUpdates(bool bStop)
     if (m_pTimeGroup)
     {
         m_pTimeGroup->stopUpdates(bStop);
+
+        if (!bStop)
+        {
+           update();
+        }
     }
 }
 
@@ -383,7 +387,7 @@ void CMainWindow::enableEditMode(bool bEnable)
 */
 void CMainWindow::turnBacklightOn()
 {
-#ifdef Q_WS_HILDON
+#ifdef Q_WS_MAEMO_5
     if (m_pOssoContext)
     {
         osso_return_t result;
@@ -457,6 +461,21 @@ void CMainWindow::onReset()
     enableEditMode(true);
 }
 
+//-----------------------------------------------------------------------------
+/**
+** Slot which gets called when the reset button is hold. Also called when
+** the countdown timer goes to zero. Resets all values.
+*/
+void CMainWindow::onRestart()
+{
+    onReset();
+    if (m_bCountDown)
+    {
+        m_pTimeGroup->setValue(m_StartTime);
+        onStart();
+    }
+}
+
 //-----------------------------------------------------------------------------
 /**
 ** Slot which gets called when the start/pause button is clicked.
@@ -491,6 +510,7 @@ void CMainWindow::onStart()
             if (bFirstStart)
             {
                 m_bCountDown = (m_pTimeGroup->value() != 0);       // Count direction depends on the start value (0:00 counts up)
+                m_StartTime = m_pTimeGroup->value();
             }
             m_pButtonStart->setIcon(m_pxPause);
             m_Timer.start(1000);
@@ -590,31 +610,12 @@ void CMainWindow::onTimeout()
 */
 void CMainWindow::onAbout()
 {
-    QString strText = tr("Tickstill by Kimmo Pekkola");
-    strText += "\n";
-    strText += tr("Double tap to toggle full screen");
-    strText += "\n";
-    strText += tr("Buzz audio sound by Mike Koenig (soundbible.com)");
-    strText += "\n\n";
-    strText += tr("Current alarm: ") + m_strAlarm;
-    QMessageBox::information(this, "Tickstill", strText);
-}
+    CAboutDialog dlg(this);
+    dlg.exec();
 
-//-----------------------------------------------------------------------------
-/**
-** Slot which gets called when the menu item is selected. Opens a file dialog
-** for the user to choose the alarm sound/file.
-*/
-void CMainWindow::onChooseAlarm()
-{
-    QString strFileName = QFileDialog::getOpenFileName(this, tr("Choose audio file or executable"));
-    if (!strFileName.isEmpty())
-    {
-        m_strAlarm = strFileName;
-
-        QSettings settings;
-        settings.setValue("Alarm", m_strAlarm);
-   }
+    // Update the alarm in case it was changed
+    QSettings settings;
+    m_strAlarm = settings.value("Alarm").toString();
 }
 
 //-----------------------------------------------------------------------------
