@@ -18,6 +18,7 @@
 //-----------------------------------------------------------------------------
 /* TODO
 ** - Settings dialog: Alarm file (choose from ringtones + "More" to choose any file)
+** - "Restart" button for the count down
 */
 //-----------------------------------------------------------------------------
 
@@ -61,10 +62,10 @@ public:
 
 public slots:
     void onReset();
+    void onRestart();
     void onStart();
     void onTimeout();
     void onAbout();
-    void onChooseAlarm();
     void onShowClock();
     void onNightMode();
     void onPresets();
@@ -99,6 +100,7 @@ private:
 
     QTimer m_Timer;                  ///< Timer for the count down/up
     bool m_bCountDown;               ///< True if timer counts down
+    int m_StartTime;                 ///< The time countdown started from
 
     QString m_strAlarm;              ///< Sound or file to be executed when counter goes to 0
 
@@ -107,7 +109,7 @@ private:
     static QColor c_Colors[Color_Last];     ///< The array of common colors
     static QPixmap* c_Pixmaps[Pixmap_Last];  ///< The array of common pixmaps
 
-#ifdef Q_WS_HILDON
+#ifdef Q_WS_MAEMO_5
     osso_context_t* m_pOssoContext;  ///< The OSSO context for backlight
 #endif
 };
