@@ -21,7 +21,7 @@
 #include <QtCore>
 #include <QtGui>
 
-#ifdef Q_WS_HILDON
+#ifdef Q_WS_MAEMO_5
 #include <libosso.h>
 #endif
 
